#!/usr/bin/python
import glob
from treecutter.page import Page

class Link():
    """Class representing a webpage on the site"""
    def __init__(self,link):
        self._link = link
        # find the representations of the link.
        self._pages = []
        path = link
        if self._link[-1] == '/':
            path = path+'index'
        lang = self._scan_languages(path)
        for l in lang:
            self._pages.append(Page(self,l))

    def add_page(self,l):
        self._pages.append(Page(self,l))

    def _scan_languages(self,path):
        lang = []
        for l in  glob.glob('.'+path+'*'):
            ls = l.split('.')
            if len(ls) > 3 and ls[3] == 'xml':
                lang.append((ls[2],l))
        return lang

    def link(self):
        return self._link

    def prepare(self):
        for page in self._pages:
            page.prepare()

    def languages(self):
        p = []
        for page in self._pages:
            p.append(page.language())
        return p

    def render(self, style):
        for page in self._pages:
            page.render(style)

    def template(self,sitemap,style,tdir):
        for page in self._pages:
            page.template(sitemap,style,tdir)

    def page(self,lang):
        for page in self._pages:
            if page.language()==lang:
                return page
        return None

    def resources(self):
        res  = set()
        for page in self._pages:
            res = res.union(page.resources())
        return res
